@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -115,8 +115,8 @@ QString ConfirmBeforeDeletingRule::ruleTypeToString(ConfirmBeforeDeletingRule::R
 bool ConfirmBeforeDeletingRule::deletingNeedToConfirm(const Akonadi::Item &item, QString &checkFoundInfo) const
 {
     bool needToConfirm = false;
-    if (item.hasPayload<KMime::Message::Ptr>()) {
-        auto msg = item.payload<KMime::Message::Ptr>();
+    if (item.hasPayload<std::shared_ptr<KMime::Message>>()) {
+        auto msg = item.payload<std::shared_ptr<KMime::Message>>();
         switch (mRuleType) {
         case Body: {
             const auto ba = msg->body();
@@ -127,7 +127,7 @@ bool ConfirmBeforeDeletingRule::deletingNeedToConfirm(const Akonadi::Item &item,
             break;
         }
         case Subject: {
-            if (auto subject = msg->subject(false)) {
+            if (auto subject = msg->subject(KMime::CreatePolicy::DontCreate)) {
                 const QString subjectStr = subject->asUnicodeString();
                 if (subjectStr.contains(pattern())) {
                     needToConfirm = true;
@@ -137,7 +137,7 @@ bool ConfirmBeforeDeletingRule::deletingNeedToConfirm(const Akonadi::Item &item,
             break;
         }
         case To: {
-            if (auto to = msg->to(false)) {
+            if (auto to = msg->to(KMime::CreatePolicy::DontCreate)) {
                 const QString toStr = to->asUnicodeString();
                 if (toStr.contains(pattern())) {
                     needToConfirm = true;
@@ -147,7 +147,7 @@ bool ConfirmBeforeDeletingRule::deletingNeedToConfirm(const Akonadi::Item &item,
             break;
         }
         case Cc: {
-            if (auto cc = msg->cc(false)) {
+            if (auto cc = msg->cc(KMime::CreatePolicy::DontCreate)) {
                 const QString ccStr = cc->asUnicodeString();
                 if (ccStr.contains(pattern())) {
                     needToConfirm = true;
@@ -157,7 +157,7 @@ bool ConfirmBeforeDeletingRule::deletingNeedToConfirm(const Akonadi::Item &item,
             break;
         }
         case Bcc: {
-            if (auto bcc = msg->bcc(false)) {
+            if (auto bcc = msg->bcc(KMime::CreatePolicy::DontCreate)) {
                 const QString bccStr = bcc->asUnicodeString();
                 if (bccStr.contains(pattern())) {
                     needToConfirm = true;
@@ -194,19 +194,21 @@ bool ConfirmBeforeDeletingRule::deletingNeedToConfirm(const Akonadi::Item &item,
     return needToConfirm;
 }
 
-void ConfirmBeforeDeletingRule::generateConfirmMessageInfo(const KMime::Message::Ptr &msg, QString &checkFoundInfo) const
+void ConfirmBeforeDeletingRule::generateConfirmMessageInfo(const std::shared_ptr<KMime::Message> &msg, QString &checkFoundInfo) const
 {
     QString subjectStr;
-    if (auto subject = msg->subject(false)) {
+    if (auto subject = msg->subject(KMime::CreatePolicy::DontCreate)) {
         subjectStr = subject->asUnicodeString();
     }
     checkFoundInfo = i18n("The message with subject \'%2\' contains \'%1\'", pattern(), subjectStr);
 }
 
-void ConfirmBeforeDeletingRule::generateConfirmMessageInfoFromStatus(const KMime::Message::Ptr &msg, QString &checkFoundInfo, const QString &statusStr) const
+void ConfirmBeforeDeletingRule::generateConfirmMessageInfoFromStatus(const std::shared_ptr<KMime::Message> &msg,
+                                                                     QString &checkFoundInfo,
+                                                                     const QString &statusStr) const
 {
     QString subjectStr;
-    if (auto subject = msg->subject(false)) {
+    if (auto subject = msg->subject(KMime::CreatePolicy::DontCreate)) {
         subjectStr = subject->asUnicodeString();
     }
     checkFoundInfo = i18n("The message with subject \'%1\' is %2", subjectStr, statusStr);
