@@ -4,7 +4,7 @@
   SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -392,7 +392,7 @@ public:
         QString receiver;
         KIdentityManagementCore::IdentityManager *im = KIdentityManagementCore::IdentityManager::self();
 
-        KMime::Types::Mailbox::List addrs;
+        QList<KMime::Types::Mailbox> addrs;
         if (auto header = node->topLevel()->header<KMime::Headers::To>()) {
             addrs = header->mailboxes();
         }
@@ -406,7 +406,7 @@ public:
             }
         }
 
-        KMime::Types::Mailbox::List ccaddrs;
+        QList<KMime::Types::Mailbox> ccaddrs;
         if (auto header = node->topLevel()->header<KMime::Headers::Cc>()) {
             ccaddrs = header->mailboxes();
         }
@@ -503,7 +503,7 @@ public:
     {
         qCDebug(TEXT_CALENDAR_LOG) << "Mailing message:" << iCal;
 
-        KMime::Message::Ptr msg(new KMime::Message);
+        std::shared_ptr<KMime::Message> msg(new KMime::Message);
         if (MessageViewer::MessageViewerSettings::self()->exchangeCompatibleInvitations()) {
             msg->subject()->fromUnicodeString(status);
             QString tsubject = subject;
@@ -578,7 +578,7 @@ public:
         // Setting the identity here is important, as that is used to select the correct
         // transport later
         KIdentityManagementCore::IdentityManager *im = KIdentityManagementCore::IdentityManager::self();
-        const KIdentityManagementCore::Identity identity = im->identityForAddress(findReceiver(viewerInstance->message().data()));
+        const KIdentityManagementCore::Identity identity = im->identityForAddress(findReceiver(viewerInstance->message().get()));
 
         const bool nullIdentity = (identity == KIdentityManagementCore::Identity::null());
 
@@ -679,7 +679,7 @@ public:
         if (incidence->organizer().isEmpty()) {
             QString tname;
             QString temail;
-            KMime::Message::Ptr message = viewerInstance->message();
+            std::shared_ptr<KMime::Message> message = viewerInstance->message();
             KEmailAddress::extractEmailAddressAndName(message->sender()->asUnicodeString(), temail, tname);
             incidence->setOrganizer(Person(tname, temail));
         }
