@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,7 +33,7 @@ EventEditTest::EventEditTest(QObject *parent)
     : QObject(parent)
 {
     qRegisterMetaType<Akonadi::Collection>();
-    qRegisterMetaType<KMime::Message::Ptr>();
+    qRegisterMetaType<std::shared_ptr<KMime::Message>>();
     qRegisterMetaType<KCalendarCore::Event::Ptr>();
     QStandardPaths::setTestModeEnabled(true);
 
@@ -100,10 +100,10 @@ void EventEditTest::shouldEmitMessageChanged()
 {
     MessageViewer::EventEdit edit;
     QSignalSpy spy(&edit, &MessageViewer::EventEdit::messageChanged);
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     edit.setMessage(msg);
     QCOMPARE(spy.count(), 1);
-    QCOMPARE(spy.at(0).at(0).value<KMime::Message::Ptr>(), msg);
+    QCOMPARE(spy.at(0).at(0).value<std::shared_ptr<KMime::Message>>(), msg);
 }
 
 void EventEditTest::shouldNotEmitWhenCollectionIsNotChanged()
@@ -118,7 +118,7 @@ void EventEditTest::shouldNotEmitWhenCollectionIsNotChanged()
 void EventEditTest::shouldNotEmitWhenMessageIsNotChanged()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     edit.setMessage(msg);
     QSignalSpy spy(&edit, &MessageViewer::EventEdit::messageChanged);
     edit.setMessage(msg);
@@ -134,10 +134,10 @@ void EventEditTest::shouldEmitEventWhenPressEnter()
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
     QVERIFY(edit.isVisible());
 
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     const QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
     auto eventedit = edit.findChild<QLineEdit *>(QStringLiteral("eventedit"));
     eventedit->setFocus();
@@ -153,10 +153,10 @@ void EventEditTest::shouldHideWidgetWhenPressEnter()
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
     QVERIFY(edit.isVisible());
 
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     const QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
     auto eventedit = edit.findChild<QLineEdit *>(QStringLiteral("eventedit"));
     QTest::keyClick(eventedit, Qt::Key_Enter);
@@ -183,9 +183,9 @@ void EventEditTest::shouldHideWidgetWhenSaveClicked()
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
 
-    KMime::Message::Ptr msg(new KMime::Message);
-    msg->subject(true)->fromUnicodeString(QStringLiteral("Test Note"));
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(QStringLiteral("Test Note"));
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
     auto save = edit.findChild<QPushButton *>(QStringLiteral("save-button"));
     QTest::mouseClick(save, Qt::LeftButton);
@@ -230,7 +230,7 @@ void EventEditTest::shouldSaveCollectionSettingsWhenDeleteWidget()
 void EventEditTest::shouldNotEmitCreateEventWhenDateIsInvalid()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
 
     auto startDateTime = edit.findChild<MessageViewer::EventDateTimeWidget *>(QStringLiteral("startdatetimeedit"));
     startDateTime->setDateTime(QDateTime());
@@ -239,8 +239,8 @@ void EventEditTest::shouldNotEmitCreateEventWhenDateIsInvalid()
     endDateTime->setDateTime(QDateTime());
 
     QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
     auto eventedit = edit.findChild<QLineEdit *>(QStringLiteral("eventedit"));
     QSignalSpy spy(&edit, &MessageViewer::EventEdit::createEvent);
@@ -251,10 +251,10 @@ void EventEditTest::shouldNotEmitCreateEventWhenDateIsInvalid()
 void EventEditTest::shouldEventHasCorrectSubject()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
     auto noteedit = edit.findChild<QLineEdit *>(QStringLiteral("eventedit"));
     QVERIFY(noteedit);
@@ -269,10 +269,10 @@ void EventEditTest::shouldEventHasCorrectSubject()
 void EventEditTest::shouldSelectLineWhenPutMessage()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
     auto noteedit = edit.findChild<QLineEdit *>(QStringLiteral("eventedit"));
     QVERIFY(noteedit);
@@ -284,10 +284,10 @@ void EventEditTest::shouldSelectLineWhenPutMessage()
 void EventEditTest::shouldHaveCorrectStartEndDateTime()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
 
     QDateTime currentDateTime = QDateTime::currentDateTime();
@@ -352,9 +352,9 @@ void EventEditTest::shouldEnsureEndDateIsNotBeforeStartDate()
 void EventEditTest::shouldEnabledSaveOpenEditorButton()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
-    msg->subject(true)->fromUnicodeString(QStringLiteral("Test note"));
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(QStringLiteral("Test note"));
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
 
     auto noteedit = edit.findChild<QLineEdit *>(QStringLiteral("eventedit"));
@@ -380,10 +380,10 @@ void EventEditTest::shouldEnabledSaveOpenEditorButton()
 void EventEditTest::shouldUpdateStartEndDateWhenReopenIt()
 {
     MessageViewer::EventEdit edit;
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     const QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
 
     QDateTime currentDateTime = QDateTime::currentDateTime();
@@ -429,10 +429,10 @@ void EventEditTest::shouldDisabledSaveOpenEditorButtonWhenCollectionComboBoxIsEm
     auto akonadicombobox = edit.findChild<Akonadi::CollectionComboBox *>(QStringLiteral("akonadicombobox"));
     // Create an empty combobox
     akonadicombobox->setModel(new QStandardItemModel());
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     const QString subject = QStringLiteral("Test Note");
-    msg->subject(true)->fromUnicodeString(subject);
-    msg->subject(false)->setRFC2047Charset("us-ascii");
+    msg->subject(KMime::CreatePolicy::Create)->fromUnicodeString(subject);
+    msg->subject(KMime::CreatePolicy::DontCreate)->setRFC2047Charset("us-ascii");
     edit.setMessage(msg);
 
     auto openEditor = edit.findChild<QPushButton *>(QStringLiteral("open-editor-button"));
