@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ ViewerPluginAI::ViewerPluginAI(QObject *parent, const QList<QVariant> &)
 
 ViewerPluginInterface *ViewerPluginAI::createView(QWidget *parent, KActionCollection *ac)
 {
-    MessageViewer::ViewerPluginInterface *view = new MessageViewer::ViewerPluginAIInterface(ac, parent);
+    auto view = new MessageViewer::ViewerPluginAIInterface(ac, parent);
     return view;
 }
 
@@ -28,14 +28,6 @@ QString ViewerPluginAI::viewerPluginName() const
     return QStringLiteral("translator");
 }
 
-void MessageViewer::ViewerPluginAI::showConfigureDialog(QWidget *parent)
-{
-    /*
-    TextTranslator::TranslatorConfigureDialog dialog(parent);
-    dialog.exec();
-    */
-}
-
 bool MessageViewer::ViewerPluginAI::hasConfigureDialog() const
 {
     return false;
