@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,6 +8,10 @@
 
 #include <QWidget>
 class QToolButton;
+namespace TextAutoGenerateText
+{
+class TextAutoGenerateQuickAskWidget;
+}
 class ViewerPluginAIWidget : public QWidget
 {
     Q_OBJECT
@@ -18,4 +22,5 @@ public:
 private:
     void slotCloseWidget();
     QToolButton *const mCloseButton;
+    TextAutoGenerateText::TextAutoGenerateQuickAskWidget *const mTextAutoGenerateQuickAskWidget;
 };
